<%inherit file="/base/index.html" /> <%namespace file="/base/formViews.html" name="formViews" import="*"/> <%def name="heading()">

# History of Form ${c.form.id}

## Current Version

##${h.literal(c.form.getIGTHTMLTable(True))} ${h.literal(c.form.getHTMLRepresentation())}

## Previous Versions

% for formBackup in c.formBackups: <% formBackup.fromJSON() %> Change made ${h.pretty_date(formBackup.datetimeModified)} (${formBackup.datetimeModified.strftime('%b %d, %Y at %I:%M %p UTC')}) by ${formBackup.backuper.firstName} ${formBackup.backuper.lastName}
${h.literal(formBackup.getHTMLRepresentation(formBackup=True))}
% endfor